==> sloancone-0.4.2.tar.gz: sloancone-0.4.2/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/sloancone/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.md') as f:
        return f.read()


install_requires = [
    'pyyaml',
    'sloancone',
    'fundamentals',
    'python-dateutil',
    'astrocalc',
    'requests',
    'eventlet',
    'unicodecsv',
    'numpy'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    c_exclude_list = ['healpy', 'astropy',
                      'numpy', 'sherlock', 'wcsaxes', 'HMpTy', 'ligo-gracedb']
    for e in c_exclude_list:
        try:
            install_requires.remove(e)
        except:
            pass

setup(name="sloancone",
      version=__version__,
      description="SDSS conesearching tools via the CL or Python API. Return conesearch results, or simply check whether or not a location in the sky has been covered by SDSS.",
      long_description=readme(),
      long_description_content_type='text/markdown',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.7',
          'Topic :: Utilities',
      ],
      keywords=['astronomy, conesearch, sdss'],
      url='https://github.com/thespacedoctor/sloancone',
      download_url='https://github.com/thespacedoctor/sloancone/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(exclude=["*tests*"]),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['sloancone=sloancone.cl_utils:main'],
      },
      zip_safe=False)

==> sloancone-0.4.3.tar.gz: sloancone-0.4.3/setup.py <==
from setuptools import setup, find_packages
import os

moduleDirectory = os.path.dirname(os.path.realpath(__file__))
exec(open(moduleDirectory + "/sloancone/__version__.py").read())


def readme():
    with open(moduleDirectory + '/README.md') as f:
        return f.read()


install_requires = [
    'pyyaml',
    'sloancone',
    'fundamentals',
    'python-dateutil',
    'astrocalc',
    'requests',
    'eventlet',
    'unicodecsv',
    'numpy'
]

# READ THE DOCS SERVERS
exists = os.path.exists("/home/docs/")
if exists:
    install_requires = ['fundamentals']

setup(name="sloancone",
      version=__version__,
      description="SDSS conesearching tools via the CL or Python API. Return conesearch results, or simply check whether or not a location in the sky has been covered by SDSS.",
      long_description=readme(),
      long_description_content_type='text/markdown',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3.9',
          'Topic :: Utilities',
      ],
      keywords=['astronomy, conesearch, sdss'],
      url='https://github.com/thespacedoctor/sloancone',
      download_url='https://github.com/thespacedoctor/sloancone/archive/v%(__version__)s.zip' % locals(
      ),
      author='David Young',
      author_email='davidrobertyoung@gmail.com',
      license='MIT',
      packages=find_packages(exclude=["*tests*"]),
      include_package_data=True,
      install_requires=install_requires,
      test_suite='nose2.collector.collector',
      tests_require=['nose2', 'cov-core'],
      entry_points={
          'console_scripts': ['sloancone=sloancone.cl_utils:main'],
      },
      zip_safe=False)
